pub struct ResolvedServerConfig {
pub url: Option<String>,
pub api_key: Option<String>,
pub project: Option<String>,
pub fallback_to_local: bool,
}Expand description
Resolved server configuration with all sources merged.
Fields
url: Option<String>api_key: Option<String>project: Option<String>fallback_to_local: boolImplementations
Sourceimpl ResolvedServerConfig
impl ResolvedServerConfig
Sourcepub fn is_configured(&self) -> bool
pub fn is_configured(&self) -> bool
Returns true if server is configured (has a URL).
Sourcepub fn create_client(&self) -> Result<Option<BaselineClient>>
pub fn create_client(&self) -> Result<Option<BaselineClient>>
Creates a BaselineClient from this configuration.
Sourcepub fn create_fallback_client(
&self,
fallback_dir: Option<&Path>,
) -> Result<Option<FallbackClient>>
pub fn create_fallback_client( &self, fallback_dir: Option<&Path>, ) -> Result<Option<FallbackClient>>
Creates a FallbackClient if fallback is enabled and server is configured.
Sourcepub fn require_fallback_client(
&self,
fallback_dir: Option<&Path>,
error_msg: &str,
) -> Result<FallbackClient>
pub fn require_fallback_client( &self, fallback_dir: Option<&Path>, error_msg: &str, ) -> Result<FallbackClient>
Returns a baseline client for server operations, or an error if not configured.